// ../presets/dist/index.mjs
var breakpoints = {
  sm: "640px",
  md: "768px",
  lg: "1024px",
  xl: "1280px",
  "2xl": "1536px"
};
var conditions = {
  hover: "&:where(:hover, [data-hover])",
  focus: "&:where(:focus, [data-focus])",
  focusWithin: "&:focus-within",
  focusVisible: "&:where(:focus-visible, [data-focus-visible])",
  disabled: "&:where(:disabled, [disabled], [data-disabled])",
  active: "&:where(:active, [data-active])",
  visited: "&:visited",
  target: "&:target",
  readOnly: "&:where(:read-only, [data-read-only])",
  readWrite: "&:read-write",
  empty: "&:where(:empty, [data-empty])",
  checked: "&:where(:checked, [data-checked], [aria-checked=true])",
  enabled: "&:enabled",
  expanded: "&:where([aria-expanded=true], [data-expanded])",
  highlighted: "&[data-highlighted]",
  before: "&::before",
  after: "&::after",
  firstLetter: "&::first-letter",
  firstLine: "&::first-line",
  marker: "&::marker",
  selection: "&::selection",
  file: "&::file-selector-button",
  backdrop: "&::backdrop",
  first: "&:first-child",
  last: "&:last-child",
  only: "&:only-child",
  even: "&:even",
  odd: "&:odd",
  firstOfType: "&:first-of-type",
  lastOfType: "&:last-of-type",
  onlyOfType: "&:only-of-type",
  peerFocus: ".peer:where(:focus, [data-focus]) ~ &",
  peerHover: ".peer:where(:hover, [data-hover]) ~ &",
  peerActive: ".peer:where(:active, [data-active]) ~ &",
  peerFocusWithin: ".peer:focus-within ~ &",
  peerFocusVisible: ".peer:where(:focus-visible, [data-focus-visible]) ~ &",
  peerDisabled: ".peer:where(:disabled, [disabled], [data-disabled]) ~ &",
  peerChecked: ".peer:where(:checked, [data-checked], [aria-checked=true]) ~ &",
  peerInvalid: ".peer:where(:invalid, [data-invalid], [aria-invalid=true]) ~ &",
  peerExpanded: ".peer:where([aria-expanded=true], [data-expanded]) ~ &",
  peerPlaceholderShown: ".peer:placeholder-shown ~ &",
  groupFocus: ".group:where(:focus, [data-focus]) &",
  groupHover: ".group:where(:hover, [data-hover]) &",
  groupActive: ".group:where(:active, [data-active]) &",
  groupFocusWithin: ".group:focus-within &",
  groupFocusVisible: ".group:where(:focus-visible, [data-focus-visible]) &",
  groupDisabled: ".group:where(:disabled, [disabled], [data-disabled]) &",
  groupChecked: ".group:where(:checked, [data-checked], [aria-checked=true]) &",
  groupExpanded: ".group:where([aria-expanded=true], [data-expanded]) &",
  groupInvalid: ".group:invalid &",
  indeterminate: "&:where(:indeterminate, [data-indeterminate], [aria-checked=mixed])",
  required: "&:required",
  valid: "&:where(:valid, [data-valid])",
  invalid: "&:where(:invalid, [data-invalid])",
  autofill: "&:autofill",
  inRange: "&:in-range",
  outOfRange: "&:out-of-range",
  placeholder: "&:placeholder",
  placeholderShown: "&:placeholder-shown",
  pressed: "&:where([aria-pressed=true], [data-pressed])",
  selected: "&:where([aria-selected=true], [data-selected])",
  default: "&:default",
  optional: "&:optional",
  open: "&[open]",
  fullscreen: "&:fullscreen",
  loading: "&:where([data-loading], [aria-busy=true])",
  currentPage: "&[aria-current=page]",
  currentStep: "&[aria-current=step]",
  motionReduce: "@media (prefers-reduced-motion: reduce)",
  motionSafe: "@media (prefers-reduced-motion: no-preference)",
  print: "@media print",
  landscape: "@media (orientation: landscape)",
  portrait: "@media (orientation: portrait)",
  dark: " &.dark, .dark &",
  light: " &.light, .light &",
  osDark: "@media (prefers-color-scheme: dark)",
  osLight: "@media (prefers-color-scheme: light)",
  highConstrast: "@media (forced-colors: active)",
  lessContrast: "@media (prefers-contrast: less)",
  moreContrast: "@media (prefers-contrast: more)",
  ltr: "[dir=ltr] &",
  rtl: "[dir=rtl] &",
  scrollbar: "&::-webkit-scrollbar",
  scrollbarThumb: "&::-webkit-scrollbar-thumb",
  scrollbarTrack: "&::-webkit-scrollbar-track"
};
var keyframes = {
  spin: {
    to: {
      transform: "rotate(360deg)"
    }
  },
  ping: {
    "75%, 100%": {
      transform: "scale(2)",
      opacity: "0"
    }
  },
  pulse: {
    "50%": {
      opacity: ".5"
    }
  },
  bounce: {
    "0%, 100%": {
      transform: "translateY(-25%)",
      animationTimingFunction: "cubic-bezier(0.8,0,1,1)"
    },
    "50%": {
      transform: "none",
      animationTimingFunction: "cubic-bezier(0,0,0.2,1)"
    }
  }
};
var animations = {
  spin: { value: "spin 1s linear infinite" },
  ping: { value: "ping 1s cubic-bezier(0, 0, 0.2, 1) infinite" },
  pulse: { value: "pulse 2s cubic-bezier(0.4, 0, 0.6, 1) infinite" },
  bounce: { value: "bounce 1s infinite" }
};
var colors = {
  current: { value: "currentColor" },
  black: { value: "#000" },
  white: { value: "#fff" },
  transparent: { value: "rgb(0 0 0 / 0)" },
  rose: {
    50: { value: "#fff1f2" },
    100: { value: "#ffe4e6" },
    200: { value: "#fecdd3" },
    300: { value: "#fda4af" },
    400: { value: "#fb7185" },
    500: { value: "#f43f5e" },
    600: { value: "#e11d48" },
    700: { value: "#be123c" },
    800: { value: "#9f1239" },
    900: { value: "#881337" }
  },
  pink: {
    50: { value: "#fdf2f8" },
    100: { value: "#fce7f3" },
    200: { value: "#fbcfe8" },
    300: { value: "#f9a8d4" },
    400: { value: "#f472b6" },
    500: { value: "#ec4899" },
    600: { value: "#db2777" },
    700: { value: "#be185d" },
    800: { value: "#9d174d" },
    900: { value: "#831843" }
  },
  fuchsia: {
    50: { value: "#fdf4ff" },
    100: { value: "#fae8ff" },
    200: { value: "#f5d0fe" },
    300: { value: "#f0abfc" },
    400: { value: "#e879f9" },
    500: { value: "#d946ef" },
    600: { value: "#c026d3" },
    700: { value: "#a21caf" },
    800: { value: "#86198f" },
    900: { value: "#701a75" }
  },
  purple: {
    50: { value: "#f5f3ff" },
    100: { value: "#ede9fe" },
    200: { value: "#ddd6fe" },
    300: { value: "#c4b5fd" },
    400: { value: "#a78bfa" },
    500: { value: "#8b5cf6" },
    600: { value: "#7c3aed" },
    700: { value: "#6d28d9" },
    800: { value: "#5b21b6" },
    900: { value: "#4c1d95" }
  },
  indigo: {
    50: { value: "#eef2ff" },
    100: { value: "#e0e7ff" },
    200: { value: "#c7d2fe" },
    300: { value: "#a5b4fc" },
    400: { value: "#818cf8" },
    500: { value: "#6366f1" },
    600: { value: "#4f46e5" },
    700: { value: "#4338ca" },
    800: { value: "#3730a3" },
    900: { value: "#312e81" }
  },
  blue: {
    50: { value: "#eff6ff" },
    100: { value: "#dbeafe" },
    200: { value: "#bfdbfe" },
    300: { value: "#93c5fd" },
    400: { value: "#60a5fa" },
    500: { value: "#3b82f6" },
    600: { value: "#2563eb" },
    700: { value: "#1d4ed8" },
    800: { value: "#1e40af" },
    900: { value: "#1e3a8a" }
  },
  sky: {
    50: { value: "#f0f9ff" },
    100: { value: "#e0f2fe" },
    200: { value: "#bae6fd" },
    300: { value: "#7dd3fc" },
    400: { value: "#38bdf8" },
    500: { value: "#0ea5e9" },
    600: { value: "#0284c7" },
    700: { value: "#0369a1" },
    800: { value: "#075985" },
    900: { value: "#0c4a6e" }
  },
  cyan: {
    50: { value: "#ecfeff" },
    100: { value: "#cffafe" },
    200: { value: "#a5f3fc" },
    300: { value: "#67e8f9" },
    400: { value: "#22d3ee" },
    500: { value: "#06b6d4" },
    600: { value: "#0891b2" },
    700: { value: "#0e7490" },
    800: { value: "#155e75" },
    900: { value: "#164e63" }
  },
  teal: {
    50: { value: "#f0fdfa" },
    100: { value: "#ccfbf1" },
    200: { value: "#99f6e4" },
    300: { value: "#5eead4" },
    400: { value: "#2dd4bf" },
    500: { value: "#14b8a6" },
    600: { value: "#0d9488" },
    700: { value: "#0f766e" },
    800: { value: "#115e59" },
    900: { value: "#134e4a" }
  },
  green: {
    50: { value: "#ecfdf5" },
    100: { value: "#d1fae5" },
    200: { value: "#a7f3d0" },
    300: { value: "#6ee7b7" },
    400: { value: "#34d399" },
    500: { value: "#10b981" },
    600: { value: "#059669" },
    700: { value: "#047857" },
    800: { value: "#065f46" },
    900: { value: "#064e3b" }
  },
  lime: {
    50: { value: "#f7fee7" },
    100: { value: "#ecfccb" },
    200: { value: "#d9f99d" },
    300: { value: "#bef264" },
    400: { value: "#a3e635" },
    500: { value: "#84cc16" },
    600: { value: "#65a30d" },
    700: { value: "#4d7c0f" },
    800: { value: "#3f6212" },
    900: { value: "#365314" }
  },
  yellow: {
    50: { value: "#fffbeb" },
    100: { value: "#fef3c7" },
    200: { value: "#fde68a" },
    300: { value: "#fcd34d" },
    400: { value: "#fbbf24" },
    500: { value: "#f59e0b" },
    600: { value: "#d97706" },
    700: { value: "#b45309" },
    800: { value: "#92400e" },
    900: { value: "#78350f" }
  },
  orange: {
    50: { value: "#fff7ed" },
    100: { value: "#ffedd5" },
    200: { value: "#fed7aa" },
    300: { value: "#fdba74" },
    400: { value: "#fb923c" },
    500: { value: "#f97316" },
    600: { value: "#ea580c" },
    700: { value: "#c2410c" },
    800: { value: "#9a3412" },
    900: { value: "#7c2d12" }
  },
  red: {
    50: { value: "#fef2f2" },
    100: { value: "#fee2e2" },
    200: { value: "#fecaca" },
    300: { value: "#fca5a5" },
    400: { value: "#f87171" },
    500: { value: "#ef4444" },
    600: { value: "#dc2626" },
    700: { value: "#b91c1c" },
    800: { value: "#991b1b" },
    900: { value: "#7f1d1d" }
  },
  gray: {
    50: { value: "#f9fafb" },
    100: { value: "#f3f4f6" },
    200: { value: "#e5e7eb" },
    300: { value: "#d1d5db" },
    400: { value: "#9ca3af" },
    500: { value: "#6b7280" },
    600: { value: "#4b5563" },
    700: { value: "#374151" },
    800: { value: "#1f2937" },
    900: { value: "#111827" }
  },
  slate: {
    50: { value: "#F8FAFC" },
    100: { value: "#F1F5F9" },
    200: { value: "#E2E8F0" },
    300: { value: "#CBD5E1" },
    400: { value: "#94A3B8" },
    500: { value: "#64748B" },
    600: { value: "#475569" },
    700: { value: "#334155" },
    800: { value: "#1E293B" },
    900: { value: "#0F172A" }
  }
};
var shadows = {
  xs: { value: "0 1px 2px 0 rgb(0 0 0 / 0.05)" },
  sm: { value: ["0 1px 3px 0 rgb(0 0 0 / 0.1)", "0 1px 2px -1px rgb(0 0 0 / 0.1)"] },
  md: { value: ["0 4px 6px -1px rgb(0 0 0 / 0.1)", "0 2px 4px -2px rgb(0 0 0 / 0.1)"] },
  lg: { value: ["0 10px 15px -3px rgb(0 0 0 / 0.1)", "0 4px 6px -4px rgb(0 0 0 / 0.1)"] },
  xl: { value: ["0 20px 25px -5px rgb(0 0 0 / 0.1)", "0 8px 10px -6px rgb(0 0 0 / 0.1)"] },
  "2xl": { value: "0 25px 50px -12px rgb(0 0 0 / 0.25)" },
  inner: { value: "inset 0 2px 4px 0 rgb(0 0 0 / 0.05)" }
};
var spacing = {
  0.5: { value: "0.125rem" },
  1: { value: "0.25rem" },
  1.5: { value: "0.375rem" },
  2: { value: "0.5rem" },
  2.5: { value: "0.625rem" },
  3: { value: "0.75rem" },
  3.5: { value: "0.875rem" },
  4: { value: "1rem" },
  5: { value: "1.25rem" },
  6: { value: "1.5rem" },
  7: { value: "1.75rem" },
  8: { value: "2rem" },
  9: { value: "2.25rem" },
  10: { value: "2.5rem" },
  11: { value: "2.75rem" },
  12: { value: "3rem" },
  14: { value: "3.5rem" },
  16: { value: "4rem" },
  20: { value: "5rem" },
  24: { value: "6rem" },
  28: { value: "7rem" },
  32: { value: "8rem" },
  36: { value: "9rem" },
  40: { value: "10rem" },
  44: { value: "11rem" },
  48: { value: "12rem" },
  52: { value: "13rem" },
  56: { value: "14rem" },
  60: { value: "15rem" },
  64: { value: "16rem" },
  72: { value: "18rem" },
  80: { value: "20rem" },
  96: { value: "24rem" }
};
var largeSizes = {
  xs: { value: "20rem" },
  sm: { value: "24rem" },
  md: { value: "28rem" },
  lg: { value: "32rem" },
  xl: { value: "36rem" },
  "2xl": { value: "42rem" },
  "3xl": { value: "48rem" },
  "4xl": { value: "56rem" },
  "5xl": { value: "64rem" },
  "6xl": { value: "72rem" },
  "7xl": { value: "80rem" },
  "8xl": { value: "90rem" },
  prose: { value: "65ch" }
};
var sizes = {
  ...spacing,
  ...largeSizes,
  full: { value: "100%" },
  min: { value: "min-content" },
  max: { value: "max-content" },
  fit: { value: "fit-content" }
};
var fontSizes = {
  "2xs": { value: "0.5rem" },
  xs: { value: "0.75rem" },
  sm: { value: "0.875rem" },
  md: { value: "1rem" },
  lg: { value: "1.125rem" },
  xl: { value: "1.25rem" },
  "2xl": { value: "1.5rem" },
  "3xl": { value: "1.875rem" },
  "4xl": { value: "2.25rem" },
  "5xl": { value: "3rem" },
  "6xl": { value: "3.75rem" },
  "7xl": { value: "4.5rem" },
  "8xl": { value: "6rem" },
  "9xl": { value: "8rem" }
};
var fontWeights = {
  thin: { value: "100" },
  extralight: { value: "200" },
  light: { value: "300" },
  normal: { value: "400" },
  medium: { value: "500" },
  semibold: { value: "600" },
  bold: { value: "700" },
  extrabold: { value: "800" },
  black: { value: "900" }
};
var letterSpacings = {
  tighter: { value: "-0.05em" },
  tight: { value: "-0.025em" },
  normal: { value: "0em" },
  wide: { value: "0.025em" },
  wider: { value: "0.05em" },
  widest: { value: "0.1em" }
};
var lineHeights = {
  none: { value: "1" },
  tight: { value: "1.25" },
  snug: { value: "1.375" },
  normal: { value: "1.5" },
  relaxed: { value: "1.625" },
  loose: { value: "2" }
};
var fonts = {
  sans: {
    value: [
      "ui-sans-serif",
      "system-ui",
      "-apple-system",
      "BlinkMacSystemFont",
      '"Segoe UI"',
      "Roboto",
      '"Helvetica Neue"',
      "Arial",
      '"Noto Sans"',
      "sans-serif",
      '"Apple Color Emoji"',
      '"Segoe UI Emoji"',
      '"Segoe UI Symbol"',
      '"Noto Color Emoji"'
    ]
  },
  serif: {
    value: ["ui-serif", "Georgia", "Cambria", '"Times New Roman"', "Times", "serif"]
  },
  mono: {
    value: [
      "ui-monospace",
      "SFMono-Regular",
      "Menlo",
      "Monaco",
      "Consolas",
      '"Liberation Mono"',
      '"Courier New"',
      "monospace"
    ]
  }
};
var textStyles = {
  xs: {
    value: {
      fontSize: "0.75rem",
      lineHeight: "1rem"
    }
  },
  sm: {
    value: {
      fontSize: "0.875rem",
      lineHeight: "1.25rem"
    }
  },
  md: {
    value: {
      fontSize: "1rem",
      lineHeight: "1.5rem"
    }
  },
  lg: {
    value: {
      fontSize: "1.125rem",
      lineHeight: "1.75rem"
    }
  },
  xl: {
    value: {
      fontSize: "1.25rem",
      lineHeight: "1.75rem"
    }
  },
  "2xl": {
    value: {
      fontSize: "1.5rem",
      lineHeight: "2rem"
    }
  },
  "3xl": {
    value: {
      fontSize: "1.875rem",
      lineHeight: "2.25rem"
    }
  },
  "4xl": {
    value: {
      fontSize: "2.25rem",
      lineHeight: "2.5rem"
    }
  },
  "5xl": {
    value: {
      fontSize: "3rem",
      lineHeight: "1"
    }
  },
  "6xl": {
    value: {
      fontSize: "3.75rem",
      lineHeight: "1"
    }
  },
  "7xl": {
    value: {
      fontSize: "4.5rem",
      lineHeight: "1"
    }
  },
  "8xl": {
    value: {
      fontSize: "6rem",
      lineHeight: "1"
    }
  },
  "9xl": {
    value: {
      fontSize: "8rem",
      lineHeight: "1"
    }
  }
};
var tokens = {
  easings: {
    default: { value: "cubic-bezier(0.4, 0, 0.2, 1)" },
    linear: { value: "linear" },
    in: { value: "cubic-bezier(0.4, 0, 1, 1)" },
    out: { value: "cubic-bezier(0, 0, 0.2, 1)" },
    "in-out": { value: "cubic-bezier(0.4, 0, 0.2, 1)" }
  },
  durations: {
    fastest: { value: "50ms" },
    faster: { value: "100ms" },
    fast: { value: "150ms" },
    normal: { value: "200ms" },
    slow: { value: "300ms" },
    slower: { value: "400ms" },
    slowest: { value: "500ms" }
  },
  radii: {
    xs: { value: "0.125rem" },
    sm: { value: "0.25rem" },
    md: { value: "0.375rem" },
    lg: { value: "0.5rem" },
    xl: { value: "0.75rem" },
    "2xl": { value: "1rem" },
    "3xl": { value: "1.5rem" },
    full: { value: "9999px" }
  },
  fontWeights,
  lineHeights,
  fonts,
  letterSpacings,
  fontSizes,
  shadows,
  // dropShadows,
  colors,
  blurs: {
    sm: { value: "4px" },
    base: { value: "8px" },
    md: { value: "12px" },
    lg: { value: "16px" },
    xl: { value: "24px" },
    "2xl": { value: "40px" },
    "3xl": { value: "64px" }
  },
  spacing,
  sizes,
  animations
};
var background = {
  backgroundPosition: {
    shorthand: "bgPosition",
    className: "bg"
  },
  backgroundPositionX: {
    shorthand: "bgPositionX",
    className: "bg-x"
  },
  backgroundPositionY: {
    shorthand: "bgPositionY",
    className: "bg-y"
  },
  backgroundAttachment: {
    shorthand: "bgAttachment",
    className: "bg"
  },
  backgroundClip: {
    shorthand: "bgClip",
    className: "bg-clip"
  },
  background: {
    shorthand: "bg",
    className: "bg",
    values: "colors"
  },
  backgroundColor: {
    shorthand: "bgColor",
    className: "bg",
    values: "colors"
  },
  backgroundOrigin: {
    shorthand: "bgOrigin",
    className: "bg-origin"
  },
  backgroundImage: {
    shorthand: "bgImage",
    className: "bg-img",
    values: "assets"
  },
  backgroundRepeat: {
    shorthand: "bgRepeat",
    className: "bg-repeat"
  },
  backgroundBlendMode: {
    shorthand: "bgBlendMode",
    className: "bg-blend"
  },
  backgroundSize: {
    shorthand: "bgSize",
    className: "bg"
  },
  backgroundGradient: {
    shorthand: "bgGradient",
    className: "bg-gradient",
    values(theme2) {
      return {
        ...theme2("gradients"),
        "to-t": "linear-gradient(to top, var(--gradient))",
        "to-tr": "linear-gradient(to top right, var(--gradient))",
        "to-r": "linear-gradient(to right, var(--gradient))",
        "to-br": "linear-gradient(to bottom right, var(--gradient))",
        "to-b": "linear-gradient(to bottom, var(--gradient))",
        "to-bl": "linear-gradient(to bottom left, var(--gradient))",
        "to-l": "linear-gradient(to left, var(--gradient))",
        "to-tl": "linear-gradient(to top left, var(--gradient))"
      };
    },
    transform(value) {
      return {
        "--gradient-stops": "var(--gradient-from), var(--gradient-to)",
        "--gradient": "var(--gradient-via-stops, var(--gradient-stops))",
        backgroundImage: value
      };
    }
  },
  textGradient: {
    className: "text-gradient",
    values(theme2) {
      return {
        ...theme2("gradients"),
        "to-t": "linear-gradient(to top, var(--gradient))",
        "to-tr": "linear-gradient(to top right, var(--gradient))",
        "to-r": "linear-gradient(to right, var(--gradient))",
        "to-br": "linear-gradient(to bottom right, var(--gradient))",
        "to-b": "linear-gradient(to bottom, var(--gradient))",
        "to-bl": "linear-gradient(to bottom left, var(--gradient))",
        "to-l": "linear-gradient(to left, var(--gradient))",
        "to-tl": "linear-gradient(to top left, var(--gradient))"
      };
    },
    transform(value) {
      return {
        "--gradient-stops": "var(--gradient-from), var(--gradient-to)",
        "--gradient": "var(--gradient-via-stops, var(--gradient-stops))",
        backgroundImage: value,
        backgroundClip: "text",
        color: "transparent"
      };
    }
  },
  gradientFrom: {
    className: "from",
    values: "colors",
    transform(value) {
      return {
        "--gradient-from": value
      };
    }
  },
  gradientTo: {
    className: "to",
    values: "colors",
    transform(value) {
      return {
        "--gradient-to": value
      };
    }
  },
  gradientVia: {
    className: "via",
    values: "colors",
    transform(value) {
      return {
        "--gradient-via-stops": "var(--gradient-from), var(--gradient-via), var(--gradient-to)",
        "--gradient-via": value
      };
    }
  }
};
var border = {
  borderRadius: {
    className: "rounded",
    values: "radii"
  },
  borderTopLeftRadius: {
    className: "rounded-tl",
    values: "radii"
  },
  borderTopRightRadius: {
    className: "rounded-tr",
    values: "radii"
  },
  borderBottomRightRadius: {
    className: "rounded-br",
    values: "radii"
  },
  borderBottomLeftRadius: {
    className: "rounded-bl",
    values: "radii"
  },
  borderTopRadius: {
    className: "rounded-t",
    values: "radii",
    transform(value) {
      return {
        borderTopLeftRadius: value,
        borderTopRightRadius: value
      };
    }
  },
  borderRightRadius: {
    className: "rounded-r",
    values: "radii",
    transform(value) {
      return {
        borderTopRightRadius: value,
        borderBottomRightRadius: value
      };
    }
  },
  borderBottomRadius: {
    className: "rounded-b",
    values: "radii",
    transform(value) {
      return {
        borderBottomLeftRadius: value,
        borderBottomRightRadius: value
      };
    }
  },
  borderLeftRadius: {
    className: "rounded-l",
    values: "radii",
    transform(value) {
      return {
        borderTopLeftRadius: value,
        borderBottomLeftRadius: value
      };
    }
  },
  borderStartStartRadius: {
    className: "rounded-start-start",
    values: "radii"
  },
  borderStartEndRadius: {
    className: "rounded-start-end",
    values: "radii"
  },
  borderStartRadius: {
    className: "rounded-start",
    values: "radii",
    transform(value) {
      return {
        borderStartStartRadius: value,
        borderStartEndRadius: value
      };
    }
  },
  borderEndStartRadius: {
    className: "rounded-end-start",
    values: "radii"
  },
  borderEndEndRadius: {
    className: "rounded-end-end",
    values: "radii"
  },
  borderEndRadius: {
    className: "rounded-end",
    values: "radii",
    transform(value) {
      return {
        borderEndStartRadius: value,
        borderEndEndRadius: value
      };
    }
  },
  border: {
    className: "border",
    values: "borders"
  },
  borderColor: {
    className: "border",
    values: "colors"
  },
  borderInline: {
    className: "border-x",
    values: "borders",
    shorthand: "borderX"
  },
  borderInlineColor: {
    className: "border-x",
    values: "colors",
    shorthand: "borderXColor"
  },
  borderBlock: {
    className: "border-y",
    values: "borders"
  },
  borderBlockColor: {
    className: "border-y",
    values: "colors",
    shorthand: "borderYColor"
  },
  borderLeft: {
    className: "border-l",
    values: "borders"
  },
  borderLeftColor: {
    className: "border-l",
    values: "colors"
  },
  borderInlineStart: {
    className: "border-s",
    values: "borders"
  },
  borderInlineStartColor: {
    className: "border-s"
  },
  borderRight: {
    className: "border-r",
    values: "borders"
  },
  borderRightColor: {
    className: "border-r",
    values: "colors"
  },
  borderInlineEnd: {
    className: "border-end",
    values: "borders"
  },
  borderInlineEndColor: {
    className: "border-end",
    values: "colors"
  },
  borderTop: {
    className: "border-t",
    values: "borders"
  },
  borderTopColor: {
    className: "border-t",
    values: "colors"
  },
  borderBottom: {
    className: "border-b",
    values: "borders"
  },
  borderBottomColor: {
    className: "border-b",
    values: "colors"
  },
  borderBlockEnd: {
    className: "border-be",
    values: "borders"
  },
  borderBlockEndColor: {
    className: "border-be",
    values: "colors"
  },
  borderBlockStart: {
    className: "border-bs",
    values: "borders"
  },
  borderBlockStartColor: {
    className: "border-bs",
    values: "colors"
  }
};
var display = {
  display: {
    className: "d"
  },
  hideFrom: {
    className: "hide",
    values: "screens",
    transform(value) {
      return {
        [`@screen ${value}`]: {
          display: "none"
        }
      };
    }
  },
  hideBelow: {
    className: "show",
    values: "screens",
    transform(value) {
      return {
        [`@screen ${value}Down`]: {
          display: "none"
        }
      };
    }
  }
};
var divide = {
  divideX: {
    className: "divide-x",
    values: { type: "string" },
    transform(value) {
      return {
        "& > :not([hidden]) ~ :not([hidden])": {
          borderLeftWidth: value,
          borderRightWidth: "0px"
        }
      };
    }
  },
  divideY: {
    className: "divide-y",
    values: { type: "string" },
    transform(value) {
      return {
        "& > :not([hidden]) ~ :not([hidden])": {
          borderTopWidth: value,
          borderBottomWidth: "0px"
        }
      };
    }
  },
  divideColor: {
    className: "divide",
    values: "colors",
    transform(value) {
      return {
        "& > :not([hidden]) ~ :not([hidden])": {
          borderColor: value
        }
      };
    }
  },
  divideStyle: {
    className: "divide",
    property: "borderStyle",
    transform(value) {
      return {
        "& > :not([hidden]) ~ :not([hidden])": {
          borderStyle: value
        }
      };
    }
  }
};
var effects = {
  boxShadow: {
    shorthand: "shadow",
    className: "shadow",
    values: "shadows"
  },
  boxShadowColor: {
    shorthand: "shadowColor",
    className: "shadow",
    values: "colors",
    transform(value) {
      return {
        "--shadow-color": value
      };
    }
  },
  mixBlendMode: {
    className: "mix-blend"
  },
  filter: {
    className: "filter",
    values: {
      auto: [
        "var(--blur)",
        "var(--brightness)",
        "var(--contrast)",
        "var(--grayscale)",
        "var(--hue-rotate)",
        "var(--invert)",
        "var(--saturate)",
        "var(--sepia)",
        "var(--drop-shadow)"
      ].join(" ")
    }
  },
  brightness: {
    className: "brightness",
    transform(value) {
      return {
        "--brightness": `brightness(${value})`
      };
    }
  },
  contrast: {
    className: "contrast",
    transform(value) {
      return {
        "--contrast": `constrast(${value})`
      };
    }
  },
  grayscale: {
    className: "grayscale",
    transform(value) {
      return {
        "--grayscale": `grayscale(${value})`
      };
    }
  },
  hueRotate: {
    className: "hue-rotate",
    transform(value) {
      return {
        "--hue-rotate": `hue-rotate(${value})`
      };
    }
  },
  invert: {
    className: "invert",
    transform(value) {
      return {
        "--invert": `invert(${value})`
      };
    }
  },
  saturate: {
    className: "saturate",
    transform(value) {
      return {
        "--saturate": `saturate(${value})`
      };
    }
  },
  sepia: {
    className: "sepia",
    transform(value) {
      return {
        "--sepia": `sepia(${value})`
      };
    }
  },
  dropShadow: {
    className: "drop-shadow",
    values: "dropShadows",
    transform(value) {
      return {
        "--drop-shadow": value
      };
    }
  },
  blur: {
    className: "blur",
    values: "blurs",
    transform(value) {
      return {
        "--blur": `blur(${value})`
      };
    }
  },
  backdropFilter: {
    className: "backdrop",
    values: {
      auto: [
        "var(--backdrop-blur)",
        "var(--backdrop-brightness)",
        "var(--backdrop-contrast)",
        "var(--backdrop-grayscale)",
        "var(--backdrop-hue-rotate)",
        "var(--backdrop-invert)",
        "var(--backdrop-saturate)",
        "var(--backdrop-sepia)"
      ].join(" ")
    }
  },
  backdropBlur: {
    className: "backdrop-blur",
    values: "blurs",
    transform(value) {
      return {
        "--backdrop-blur": `blur(${value})`
      };
    }
  },
  backdropBrightness: {
    className: "backdrop-brightness",
    transform(value) {
      return {
        "--backdrop-brightness": `brightness(${value})`
      };
    }
  },
  backdropContrast: {
    className: "backdrop-contrast",
    transform(value) {
      return {
        "--backdrop-contrast": `constrast(${value})`
      };
    }
  },
  backdropGrayscale: {
    className: "backdrop-grayscale",
    transform(value) {
      return {
        "--backdrop-grayscale": `grayscale(${value})`
      };
    }
  },
  backdropHueRotate: {
    className: "backdrop-hue-rotate",
    transform(value) {
      return {
        "--backdrop-hue-rotate": `hue-rotate(${value})`
      };
    }
  },
  backdropInvert: {
    className: "backdrop-invert",
    transform(value) {
      return {
        "--backdrop-invert": `invert(${value})`
      };
    }
  },
  backdropOpacity: {
    className: "backdrop-opacity",
    transform(value) {
      return {
        "--backdrop-opacity": value
      };
    }
  },
  backdropSaturate: {
    className: "backdrop-saturate",
    transform(value) {
      return {
        "--backdrop-saturate": `saturate(${value})`
      };
    }
  },
  backdropSepia: {
    className: "backdrop-sepia",
    transform(value) {
      return {
        "--backdrop-sepia": `sepia(${value})`
      };
    }
  }
};
var flexGrid = {
  flexBasis: {
    className: "basis",
    values(theme2) {
      return {
        ...theme2("spacing"),
        "1/2": "50%",
        "1/3": "33.333333%",
        "2/3": "66.666667%",
        "1/4": "25%",
        "2/4": "50%",
        "3/4": "75%",
        "1/5": "20%",
        "2/5": "40%",
        "3/5": "60%",
        "4/5": "80%",
        "1/6": "16.666667%",
        "2/6": "33.333333%",
        "3/6": "50%",
        "4/6": "66.666667%",
        "5/6": "83.333333%",
        "1/12": "8.333333%",
        "2/12": "16.666667%",
        "3/12": "25%",
        "4/12": "33.333333%",
        "5/12": "41.666667%",
        "6/12": "50%",
        "7/12": "58.333333%",
        "8/12": "66.666667%",
        "9/12": "75%",
        "10/12": "83.333333%",
        "11/12": "91.666667%",
        full: "100%"
      };
    }
  },
  flex: {
    className: "flex",
    values: {
      "1": "1 1 0%",
      auto: "1 1 auto",
      initial: "0 1 auto",
      none: "none"
    }
  },
  flexDirection: {
    className: "flex",
    shorthand: "flexDir"
  },
  flexGrow: {
    className: "grow"
  },
  flexShrink: {
    className: "shrink"
  },
  gridTemplateColumns: {
    className: "grid-cols",
    values: {
      "1": "repeat(1, minmax(0, 1fr))",
      "2": "repeat(2, minmax(0, 1fr))",
      "3": "repeat(3, minmax(0, 1fr))",
      "4": "repeat(4, minmax(0, 1fr))",
      "5": "repeat(5, minmax(0, 1fr))",
      "6": "repeat(6, minmax(0, 1fr))",
      "7": "repeat(7, minmax(0, 1fr))",
      "8": "repeat(8, minmax(0, 1fr))",
      "9": "repeat(9, minmax(0, 1fr))",
      "10": "repeat(10, minmax(0, 1fr))",
      "11": "repeat(11, minmax(0, 1fr))",
      "12": "repeat(12, minmax(0, 1fr))"
    }
  },
  gridTemplateRows: {
    className: "grid-cols",
    values: {
      "1": "repeat(1, minmax(0, 1fr))",
      "2": "repeat(2, minmax(0, 1fr))",
      "3": "repeat(3, minmax(0, 1fr))",
      "4": "repeat(4, minmax(0, 1fr))",
      "5": "repeat(5, minmax(0, 1fr))",
      "6": "repeat(6, minmax(0, 1fr))",
      "7": "repeat(7, minmax(0, 1fr))",
      "8": "repeat(8, minmax(0, 1fr))",
      "9": "repeat(9, minmax(0, 1fr))",
      "10": "repeat(10, minmax(0, 1fr))",
      "11": "repeat(11, minmax(0, 1fr))",
      "12": "repeat(12, minmax(0, 1fr))"
    }
  },
  gridColumn: {
    className: "col-span",
    values: {
      full: "1 / -1",
      "1": "span 1 / span 1",
      "2": "span 2 / span 2",
      "3": "span 3 / span 3",
      "4": "span 4 / span 4",
      "5": "span 5 / span 5",
      "6": "span 6 / span 6",
      "7": "span 7 / span 7",
      "8": "span 8 / span 8",
      "9": "span 9 / span 9",
      "10": "span 10 / span 10",
      "11": "span 11 / span 11",
      "12": "span 12 / span 12"
    }
  },
  gridRow: {
    className: "row-span",
    values: {
      full: "1 / -1",
      "1": "span 1 / span 1",
      "2": "span 2 / span 2",
      "3": "span 3 / span 3",
      "4": "span 4 / span 4",
      "5": "span 5 / span 5",
      "6": "span 6 / span 6",
      "7": "span 7 / span 7",
      "8": "span 8 / span 8",
      "9": "span 9 / span 9",
      "10": "span 10 / span 10",
      "11": "span 11 / span 11",
      "12": "span 12 / span 12"
    }
  },
  gridColumnStart: {
    className: "col-start"
  },
  gridColumnEnd: {
    className: "col-end"
  },
  gridAutoFlow: {
    className: "grid-flow"
  },
  gridAutoColumns: {
    className: "auto-cols",
    values: {
      min: "min-content",
      max: "max-content",
      fr: "minmax(0, 1fr)"
    }
  },
  gridAutoRows: {
    className: "auto-rows",
    values: {
      min: "min-content",
      max: "max-content",
      fr: "minmax(0, 1fr)"
    }
  },
  gap: {
    className: "gap",
    values: "spacing"
  },
  gridGap: {
    className: "gap",
    values: "spacing"
  },
  gridRowGap: {
    className: "gap-x",
    values: "spacing"
  },
  gridColumnGap: {
    className: "gap-y",
    values: "spacing"
  },
  rowGap: {
    className: "gap-x",
    values: "spacing"
  },
  columnGap: {
    className: "gap-y",
    values: "spacing"
  },
  justifyContent: {
    className: "justify"
  },
  alignContent: {
    className: "content"
  },
  alignItems: {
    className: "items"
  },
  alignSelf: {
    className: "self"
  }
};
var srMapping = {
  true: {
    position: "absolute",
    width: "1px",
    height: "1px",
    padding: "0",
    margin: "-1px",
    overflow: "hidden",
    clip: "rect(0, 0, 0, 0)",
    whiteSpace: "nowrap",
    borderWidth: "0"
  },
  false: {
    position: "static",
    width: "auto",
    height: "auto",
    padding: "0",
    margin: "0",
    overflow: "visible",
    clip: "auto",
    whiteSpace: "normal"
  }
};
var helpers = {
  srOnly: {
    className: "sr",
    values: { type: "boolean" },
    transform(value) {
      return srMapping[value] || {};
    }
  },
  debug: {
    className: "debug",
    values: { type: "boolean" },
    transform(value) {
      if (!value)
        return {};
      return {
        outline: "1px solid blue !important",
        "&>*": {
          outline: "1px solid red !important"
        }
      };
    }
  }
};
var interactivity = {
  accentColor: {
    className: "accent",
    values: "colors"
  },
  caretColor: {
    className: "caret",
    values: "colors"
  },
  scrollBehavior: {
    className: "scroll"
  },
  scrollbar: {
    className: "scrollbar",
    values: ["visible", "hidden"],
    transform(value) {
      if (value === "visible") {
        return {
          msOverflowStyle: "auto",
          scrollbarWidth: "auto",
          "&::-webkit-scrollbar": {
            display: "block"
          }
        };
      }
      if (value === "hidden") {
        return {
          msOverflowStyle: "none",
          scrollbarWidth: "none",
          "&::-webkit-scrollbar": {
            display: "none"
          }
        };
      }
    }
  },
  scrollMargin: {
    className: "scroll-m",
    values: "spacing"
  },
  scrollMarginX: {
    className: "scroll-mx",
    values: "spacing",
    property: "scrollMarginInline",
    transform(value) {
      return {
        scrollMarginInline: value
      };
    }
  },
  scrollMarginY: {
    className: "scroll-my",
    values: "spacing",
    property: "scrollMarginBlock",
    transform(value) {
      return {
        scrollMarginBlock: value
      };
    }
  },
  scrollMarginLeft: {
    className: "scroll-ml",
    values: "spacing"
  },
  scrollMarginRight: {
    className: "scroll-mr",
    values: "spacing"
  },
  scrollMarginTop: {
    className: "scroll-mt",
    values: "spacing"
  },
  scrollMarginBottom: {
    className: "scroll-mb",
    values: "spacing"
  },
  scrollMarginBlock: {
    className: "scroll-my",
    values: "spacing"
  },
  scrollMarginBlockEnd: {
    className: "scroll-mb",
    values: "spacing"
  },
  scrollMarginBlockStart: {
    className: "scroll-mt",
    values: "spacing"
  },
  scrollMarginInline: {
    className: "scroll-mx",
    values: "spacing"
  },
  scrollMarginInlineEnd: {
    className: "scroll-me",
    values: "spacing"
  },
  scrollMarginInlineStart: {
    className: "scroll-ms",
    values: "spacing"
  },
  scrollPadding: {
    className: "scroll-p",
    values: "spacing"
  },
  scrollPaddingBlock: {
    className: "scroll-pb",
    values: "spacing"
  },
  scrollPaddingBlockStart: {
    className: "scroll-pt",
    values: "spacing"
  },
  scrollPaddingBlockEnd: {
    className: "scroll-pb",
    values: "spacing"
  },
  scrollPaddingInline: {
    className: "scroll-px",
    values: "spacing"
  },
  scrollPaddingInlineEnd: {
    className: "scroll-pe",
    values: "spacing"
  },
  scrollPaddingInlineStart: {
    className: "scroll-ps",
    values: "spacing"
  },
  scrollPaddingX: {
    className: "scroll-px",
    values: "spacing",
    property: "scrollPaddingInline",
    transform(value) {
      return {
        scrollPaddingInline: value
      };
    }
  },
  scrollPaddingY: {
    className: "scroll-py",
    values: "spacing",
    property: "scrollPaddingBlock",
    transform(value) {
      return {
        scrollPaddingBlock: value
      };
    }
  },
  scrollPaddingLeft: {
    className: "scroll-pl",
    values: "spacing"
  },
  scrollPaddingRight: {
    className: "scroll-pr",
    values: "spacing"
  },
  scrollPaddingTop: {
    className: "scroll-pt",
    values: "spacing"
  },
  scrollPaddingBottom: {
    className: "scroll-pb",
    values: "spacing"
  },
  scrollSnapAlign: {
    className: "snap"
  },
  scrollSnapStop: {
    className: "snap"
  },
  scrollSnapType: {
    className: "snap",
    values: {
      none: "none",
      x: "x var(--scroll-snap-strictness)",
      y: "y var(--scroll-snap-strictness)",
      both: "both var(--scroll-snap-strictness)"
    }
  },
  scrollSnapStrictness: {
    className: "strictness",
    values: ["mandatory", "proximity"],
    transform(value) {
      return {
        "--scroll-snap-strictness": value
      };
    }
  },
  scrollSnapMargin: {
    className: "snap-m",
    values: "spacing"
  },
  scrollSnapMarginTop: {
    className: "snap-mt",
    values: "spacing"
  },
  scrollSnapMarginBottom: {
    className: "snap-mb",
    values: "spacing"
  },
  scrollSnapMarginLeft: {
    className: "snap-ml",
    values: "spacing"
  },
  scrollSnapMarginRight: {
    className: "snap-mr",
    values: "spacing"
  },
  touchAction: {
    className: "touch"
  },
  userSelect: {
    className: "select"
  }
};
var layout = {
  aspectRatio: {
    className: "aspect",
    values: {
      square: "1 / 1",
      landscape: "4 / 3",
      portrait: "3 / 4",
      wide: "16 / 9",
      ultrawide: "18 / 5",
      golden: "1.618 / 1"
    }
  },
  boxDecorationBreak: {
    className: "decoration"
  },
  zIndex: {
    className: "z"
  },
  boxSizing: {
    className: "box"
  },
  objectPosition: {
    className: "object"
  },
  objectFit: {
    className: "object"
  },
  overscrollBehavior: {
    className: "overscroll"
  },
  overscrollBehaviorX: {
    className: "overscroll-x"
  },
  overscrollBehaviorY: {
    className: "overscroll-y"
  },
  position: {
    className: "pos",
    shorthand: "pos"
  },
  top: {
    className: "t",
    values: "spacing"
  },
  left: {
    className: "l",
    values: "spacing"
  },
  insetInline: {
    className: "inset-x",
    values: "spacing"
  },
  insetBlock: {
    className: "inset-y",
    values: "spacing"
  },
  inset: {
    className: "inset",
    values: "spacing"
  },
  insetBlockEnd: {
    className: "inset-b",
    values: "spacing"
  },
  insetBlockStart: {
    className: "inset-t",
    values: "spacing"
  },
  insetInlineEnd: {
    className: "end",
    values: "spacing",
    shorthand: "insetEnd"
  },
  insetInlineStart: {
    className: "start",
    values: "spacing",
    shorthand: "insetStart"
  },
  start: {
    className: "s",
    values: "spacing",
    transform(value) {
      return {
        insetInlineStart: value
      };
    }
  },
  right: {
    className: "r",
    values: "spacing"
  },
  end: {
    className: "e",
    values: "spacing",
    transform(value) {
      return {
        insetInlineEnd: value
      };
    }
  },
  bottom: {
    className: "b",
    values: "spacing"
  },
  insetX: {
    className: "inset-x",
    values: "spacing",
    property: "insetInline",
    transform(value) {
      return {
        insetInline: value
      };
    }
  },
  insetY: {
    className: "inset-y",
    values: "spacing",
    property: "insetBlock",
    transform(value) {
      return {
        insetBlock: value
      };
    }
  },
  float: {
    className: "float",
    values: ["left", "right", "start", "end"],
    transform(value) {
      if (value === "start") {
        return {
          float: "left",
          '[dir="rtl"] &': {
            float: "right"
          }
        };
      }
      if (value === "end") {
        return {
          float: "right",
          '[dir="rtl"] &': {
            float: "left"
          }
        };
      }
      return {
        float: value
      };
    }
  },
  visibility: {
    className: "vis"
  }
};
var list = {
  listStyleType: {
    className: "list"
  },
  listStylePosition: {
    className: "list"
  },
  listStyleImage: {
    className: "list-img",
    values: "assets"
  }
};
var outline = {
  outlineWidth: {
    className: "ring",
    shorthand: "ringWidth"
  },
  outlineColor: {
    className: "ring",
    values: "colors",
    shorthand: "ringColor"
  },
  outline: {
    className: "ring",
    shorthand: "ring",
    values: "borders",
    transform(value) {
      if (value === "none") {
        return { outline: "2px solid transparent", outlineOffset: "2px" };
      }
      return { outline: value };
    }
  },
  outlineOffset: {
    className: "ring",
    shorthand: "ringOffset",
    values: "spacing"
  }
};
var widthValues = (theme2) => ({
  ...theme2("sizes"),
  "1/2": "50%",
  "1/3": "33.333333%",
  "2/3": "66.666667%",
  "1/4": "25%",
  "2/4": "50%",
  "3/4": "75%",
  "1/5": "20%",
  "2/5": "40%",
  "3/5": "60%",
  "4/5": "80%",
  "1/6": "16.666667%",
  "2/6": "33.333333%",
  "3/6": "50%",
  "4/6": "66.666667%",
  "5/6": "83.333333%",
  "1/12": "8.333333%",
  "2/12": "16.666667%",
  "3/12": "25%",
  "4/12": "33.333333%",
  "5/12": "41.666667%",
  "6/12": "50%",
  "7/12": "58.333333%",
  "8/12": "66.666667%",
  "9/12": "75%",
  "10/12": "83.333333%",
  "11/12": "91.666667%",
  screen: "100vw"
});
var heightValues = (theme2) => ({
  ...theme2("sizes"),
  "1/2": "50%",
  "1/3": "33.333333%",
  "2/3": "66.666667%",
  "1/4": "25%",
  "2/4": "50%",
  "3/4": "75%",
  "1/5": "20%",
  "2/5": "40%",
  "3/5": "60%",
  "4/5": "80%",
  "1/6": "16.666667%",
  "2/6": "33.333333%",
  "3/6": "50%",
  "4/6": "66.666667%",
  "5/6": "83.333333%"
});
var sizing = {
  width: {
    shorthand: "w",
    className: "w",
    values: widthValues
  },
  inlineSize: {
    className: "i",
    values: widthValues
  },
  height: {
    shorthand: "h",
    className: "h",
    values: heightValues
  },
  blockSize: {
    className: "b",
    values: heightValues
  },
  minHeight: {
    shorthand: "minH",
    className: "min-h",
    values: "sizes"
  },
  minBlockSize: {
    className: "min-b",
    values: "sizes"
  },
  maxHeight: {
    shorthand: "maxH",
    className: "max-h",
    values: "sizes"
  },
  maxBlockSize: {
    className: "max-b",
    values: "sizes"
  },
  minWidth: {
    shorthand: "minW",
    className: "min-w",
    values: "sizes"
  },
  minInlineSize: {
    className: "min-i",
    values: "sizes"
  },
  maxWidth: {
    shorthand: "maxW",
    className: "max-w",
    values: "sizes"
  },
  maxInlineSize: {
    className: "max-i",
    values: "sizes"
  }
};
var spacing2 = {
  padding: {
    className: "p",
    shorthand: "p",
    values: "spacing"
  },
  paddingLeft: {
    className: "pl",
    shorthand: "pl",
    values: "spacing"
  },
  paddingRight: {
    className: "pr",
    shorthand: "pr",
    values: "spacing"
  },
  paddingTop: {
    className: "pt",
    shorthand: "pt",
    values: "spacing"
  },
  paddingBottom: {
    className: "pb",
    shorthand: "pb",
    values: "spacing"
  },
  paddingBlock: {
    className: "py",
    values: "spacing"
  },
  paddingBlockEnd: {
    className: "pb",
    values: "spacing"
  },
  paddingBlockStart: {
    className: "pt",
    values: "spacing"
  },
  paddingInline: {
    className: "px",
    values: "spacing"
  },
  paddingInlineEnd: {
    className: "pe",
    shorthand: "pe",
    values: "spacing"
  },
  paddingInlineStart: {
    className: "ps",
    shorthand: "ps",
    values: "spacing"
  },
  paddingX: {
    className: "px",
    shorthand: "px",
    property: "paddingInline",
    values: "spacing",
    transform(value) {
      return {
        paddingInline: value
      };
    }
  },
  paddingY: {
    className: "py",
    shorthand: "py",
    values: "spacing",
    property: "paddingBlock",
    transform(value) {
      return {
        paddingBlock: value
      };
    }
  },
  marginLeft: {
    className: "ml",
    shorthand: "ml",
    values: "spacing"
  },
  marginRight: {
    className: "mr",
    shorthand: "mr",
    values: "spacing"
  },
  marginTop: {
    className: "mt",
    shorthand: "mt",
    values: "spacing"
  },
  marginBottom: {
    className: "mb",
    shorthand: "mb",
    values: "spacing"
  },
  margin: {
    className: "m",
    shorthand: "m",
    values: "spacing"
  },
  marginX: {
    className: "mx",
    shorthand: "mx",
    values: "spacing",
    property: "marginInline",
    transform(value) {
      return {
        marginInline: value
      };
    }
  },
  marginY: {
    className: "my",
    shorthand: "my",
    values: "spacing",
    property: "marginBlock",
    transform(value) {
      return {
        marginBlock: value
      };
    }
  },
  marginBlock: {
    className: "my",
    values: "spacing"
  },
  marginBlockEnd: {
    className: "mb",
    values: "spacing"
  },
  marginBlockStart: {
    className: "mt",
    values: "spacing"
  },
  marginInline: {
    className: "mx",
    values: "spacing"
  },
  marginInlineEnd: {
    className: "me",
    shorthand: "me",
    values: "spacing"
  },
  marginInlineStart: {
    className: "ms",
    shorthand: "ms",
    values: "spacing"
  },
  spaceX: {
    className: "space-x",
    values: "spacing",
    transform(value) {
      return {
        "& > :not([hidden]) ~ :not([hidden])": {
          marginInlineStart: value
        }
      };
    }
  },
  spaceY: {
    className: "space-y",
    values: "spacing",
    transform(value) {
      return {
        "& > :not([hidden]) ~ :not([hidden])": {
          marginBlockStart: value
        }
      };
    }
  }
};
var svg = {
  fill: {
    className: "fill",
    values: "colors"
  },
  stroke: {
    className: "stroke",
    values: "colors"
  }
};
var tables = {
  borderCollapse: {
    className: "border"
  },
  borderSpacing: {
    className: "border-spacing",
    values: "spacing"
  },
  borderSpacingX: {
    className: "border-spacing-x",
    values: "spacing",
    transform(value) {
      return {
        borderSpacing: `${value} var(--border-spacing-y)`
      };
    }
  },
  borderSpacingY: {
    className: "border-spacing-y",
    values: "spacing",
    transform(value) {
      return {
        borderSpacing: `var(--border-spacing-x) ${value}`
      };
    }
  },
  tableLayout: {
    className: "table"
  }
};
var transformTemplate = [
  "rotate(var(--rotate))",
  "scaleX(var(--scale-x))",
  "scaleY(var(--scale-y))",
  "skewX(var(--skew-x))",
  "skewY(var(--skew-y))"
];
var baseTransformTemplate = [
  "translateX(var(--translate-x))",
  "translateY(var(--translate-y))",
  ...transformTemplate
].join(" ");
var gpuTransformTemplate = [
  "translate3d(var(--translate-x), var(--translate-y), 0)",
  ...transformTemplate
].join(" ");
var transforms = {
  transform: {
    className: "transform",
    values: {
      auto: baseTransformTemplate,
      "auto-gpu": gpuTransformTemplate
    }
  },
  transformOrigin: {
    className: "origin"
  },
  scale: {
    className: "scale",
    transform(value) {
      return {
        "--scale-x": value,
        "--scale-y": value
      };
    }
  },
  scaleX: {
    className: "scale-x",
    transform(value) {
      return {
        "--scale-x": value
      };
    }
  },
  scaleY: {
    className: "scale-y",
    transform(value) {
      return {
        "--scale-y": value
      };
    }
  },
  rotate: {
    className: "rotate",
    transform(value) {
      return {
        "--rotate": value
      };
    }
  },
  translateX: {
    shorthand: "x",
    className: "translate-x",
    values(theme2) {
      return {
        ...theme2("spacing"),
        "1/2": "50%",
        "1/3": "33.333333%",
        "2/3": "66.666667%",
        "1/4": "25%",
        "2/4": "50%",
        "3/4": "75%",
        full: "100%"
      };
    },
    transform(value) {
      return {
        "--translate-x": value
      };
    }
  },
  translateY: {
    shorthand: "y",
    className: "translate-y",
    values(theme2) {
      return {
        ...theme2("spacing"),
        "1/2": "50%",
        "1/3": "33.333333%",
        "2/3": "66.666667%",
        "1/4": "25%",
        "2/4": "50%",
        "3/4": "75%",
        full: "100%"
      };
    },
    transform(value) {
      return {
        "--translate-y": value
      };
    }
  },
  skewX: {
    className: "skew-x",
    transform(value) {
      return {
        "--skew-x": value
      };
    }
  },
  skewY: {
    className: "skew-y",
    transform(value) {
      return {
        "--skew-y": value
      };
    }
  }
};
var transitions = {
  transitionTimingFunction: {
    className: "ease",
    values: "easings"
  },
  transitionDelay: {
    className: "delay",
    values: "durations"
  },
  transitionDuration: {
    className: "duration",
    values: "durations"
  },
  transitionProperty: {
    className: "transition",
    values: {
      all: "all",
      none: "none",
      opacity: "opacity",
      shadow: "box-shadow",
      transform: "transform",
      base: "color, background-color, border-color, outline-color, text-decoration-color, fill, stroke, opacity, box-shadow, transform, filter, backdrop-filter",
      background: "background, background-color",
      colors: "color, background-color, border-color, outline-color, text-decoration-color, fill, stroke"
    }
  },
  animation: {
    className: "animation",
    values: "animations"
  },
  animationDelay: {
    className: "animation-delay",
    values: "durations"
  }
};
var typography = {
  color: {
    className: "text",
    values: "colors"
  },
  fontFamily: {
    className: "font",
    values: "fonts"
  },
  fontSize: {
    className: "fs",
    values: "fontSizes"
  },
  fontWeight: {
    className: "font",
    values: "fontWeights"
  },
  fontSmoothing: {
    className: "smoothing",
    values: {
      antialiased: "antialiased",
      "subpixel-antialiased": "auto"
    },
    transform(value) {
      return {
        WebkitFontSmoothing: value
      };
    }
  },
  fontVariantNumeric: {
    className: "numeric"
  },
  letterSpacing: {
    className: "tracking",
    values: "letterSpacings"
  },
  lineHeight: {
    className: "leading",
    values: "lineHeights"
  },
  textAlign: {
    className: "text"
  },
  textDecoration: {
    className: "text-decor"
  },
  textDecorationColor: {
    className: "text-decor",
    values: "colors"
  },
  textEmphasisColor: {
    className: "text-emphasis",
    values: "colors"
  },
  textDecorationStyle: {
    className: "decoration"
  },
  textDecorationThickness: {
    className: "decoration"
  },
  textUnderlineOffset: {
    className: "underline-offset"
  },
  textTransform: {
    className: "text"
  },
  textIndent: {
    className: "indent",
    values: "spacing"
  },
  textShadow: {
    className: "text-shadow",
    values: "shadows"
  },
  textOverflow: {
    className: "text"
  },
  verticalAlign: {
    className: "align"
  },
  wordBreak: {
    className: "break"
  },
  truncate: {
    className: "truncate",
    values: { type: "boolean" },
    transform(value) {
      if (!value)
        return {};
      return {
        overflow: "hidden",
        textOverflow: "ellipsis",
        whiteSpace: "nowrap"
      };
    }
  },
  lineClamp: {
    className: "clamp",
    transform(value) {
      if (value === "none") {
        return {
          WebkitLineClamp: "unset"
        };
      }
      return {
        overflow: "hidden",
        display: "-webkit-box",
        WebkitLineClamp: value,
        WebkitBoxOrient: "vertical"
      };
    }
  }
};
var utilities = Object.assign(
  {},
  layout,
  display,
  flexGrid,
  spacing2,
  outline,
  divide,
  sizing,
  typography,
  list,
  background,
  border,
  effects,
  tables,
  transitions,
  transforms,
  interactivity,
  svg,
  helpers
);
var box = {
  properties: {},
  transform(props) {
    return props;
  }
};
var flex = {
  properties: {
    align: { type: "property", value: "alignItems" },
    justify: { type: "property", value: "justifyContent" },
    direction: { type: "property", value: "flexDirection" },
    wrap: { type: "property", value: "flexWrap" },
    basis: { type: "property", value: "flexBasis" },
    grow: { type: "property", value: "flexGrow" },
    shrink: { type: "property", value: "flexShrink" }
  },
  blocklist: [
    "alignItems",
    "justifyContent",
    "flexDirection",
    "flexDir",
    "flexWrap",
    "flexShrink",
    "flexBasis",
    "flexGrow",
    "flexFlow"
  ],
  transform(props) {
    const { direction, align, justify, wrap: wrap2, basis, grow, shrink, ...rest } = props;
    return {
      display: "flex",
      flexDirection: direction,
      alignItems: align,
      justifyContent: justify,
      flexWrap: wrap2,
      flexBasis: basis,
      flexGrow: grow,
      flexShrink: shrink,
      ...rest
    };
  }
};
var stack = {
  properties: {
    align: { type: "property", value: "alignItems" },
    justify: { type: "property", value: "justifyContent" },
    direction: { type: "property", value: "flexDirection" },
    gap: { type: "property", value: "gap" }
  },
  transform(props) {
    const { align = "flex-start", justify, direction = "column", gap = "10px", ...rest } = props;
    return {
      display: "flex",
      flexDirection: direction,
      alignItems: align,
      justifyContent: justify,
      gap,
      ...rest
    };
  }
};
var vstack = {
  jsx: "VStack",
  properties: {
    justify: { type: "property", value: "justifyContent" },
    gap: { type: "property", value: "gap" }
  },
  transform(props) {
    const { justify, gap = "10px", ...rest } = props;
    return {
      display: "flex",
      alignItems: "center",
      justifyContent: justify,
      gap,
      flexDirection: "column",
      ...rest
    };
  }
};
var hstack = {
  jsx: "HStack",
  properties: {
    justify: { type: "property", value: "justifyContent" },
    gap: { type: "property", value: "gap" }
  },
  transform(props) {
    const { justify, gap = "10px", ...rest } = props;
    return {
      display: "flex",
      alignItems: "center",
      justifyContent: justify,
      gap,
      flexDirection: "row",
      ...rest
    };
  }
};
var spacer = {
  properties: {
    size: { type: "token", value: "spacing" }
  },
  transform(props, { map }) {
    const { axis, size, ...rest } = props;
    return {
      alignSelf: "stretch",
      justifySelf: "stretch",
      flex: map(size, (v) => v == null ? "1" : `0 0 ${v}`),
      ...rest
    };
  }
};
var circle = {
  properties: {
    size: { type: "property", value: "width" }
  },
  transform(props) {
    const { size, ...rest } = props;
    return {
      display: "flex",
      alignItems: "center",
      justifyContent: "center",
      width: size,
      height: size,
      borderRadius: "9999px",
      flex: "0 0 auto",
      ...rest
    };
  }
};
var absoluteCenter = {
  properties: {
    axis: { type: "enum", value: ["x", "y", "both"] }
  },
  transform(props, { map }) {
    const { axis = "both", ...rest } = props;
    return {
      position: "absolute",
      top: map(axis, (v) => v === "x" ? "auto" : "50%"),
      left: map(axis, (v) => v === "y" ? "auto" : "50%"),
      transform: map(
        axis,
        (v) => v === "both" ? "translate(-50%, -50%)" : v === "x" ? "translateX(-50%)" : "translateY(-50%)"
      ),
      ...rest
    };
  }
};
var grid = {
  properties: {
    gap: { type: "property", value: "gap" },
    gapX: { type: "property", value: "gap" },
    gapY: { type: "property", value: "gap" },
    columns: { type: "number" },
    minChildWidth: { type: "token", value: "sizes", property: "width" }
  },
  transform(props, { map }) {
    const { gapX, gapY, gap = gapX || gapY ? void 0 : "10px", columns, minChildWidth, ...rest } = props;
    return {
      gridTemplateColumns: columns != null ? map(columns, (v) => `repeat(${v}, minmax(0, 1fr))`) : minChildWidth != null ? map(minChildWidth, (v) => `repeat(auto-fit, minmax(${v}, 1fr))`) : void 0,
      display: "grid",
      gap,
      columnGap: gapX,
      rowGap: gapY,
      ...rest
    };
  }
};
var gridItem = {
  properties: {
    colSpan: { type: "number" },
    rowSpan: { type: "number" },
    colStart: { type: "number" },
    rowStart: { type: "number" },
    colEnd: { type: "number" },
    rowEnd: { type: "number" }
  },
  transform(props, { map }) {
    const { colSpan, rowSpan, colStart, rowStart, colEnd, rowEnd, ...rest } = props;
    const spanFn = (v) => v === "auto" ? v : `span ${v}`;
    return {
      gridColumn: colSpan != null ? map(colSpan, spanFn) : void 0,
      gridRow: rowSpan != null ? map(rowSpan, spanFn) : void 0,
      gridColumnEnd: colEnd,
      gridRowEnd: rowEnd,
      ...rest
    };
  }
};
var wrap = {
  properties: {
    gap: { type: "property", value: "gap" },
    gapX: { type: "property", value: "gap" },
    gapY: { type: "property", value: "gap" },
    align: { type: "property", value: "alignItems" },
    justify: { type: "property", value: "justifyContent" }
  },
  transform(props) {
    const { gapX, gapY, gap = gapX || gapY ? void 0 : "10px", align, justify, ...rest } = props;
    return {
      display: "flex",
      flexWrap: "wrap",
      alignItems: align,
      justifyContent: justify,
      gap,
      columnGap: gapX,
      rowGap: gapY,
      ...rest
    };
  }
};
var container = {
  properties: {
    centerContent: { type: "boolean" }
  },
  transform(props) {
    const { centerContent, ...rest } = props;
    return {
      position: "relative",
      width: "100%",
      maxWidth: "60ch",
      marginX: "auto",
      ...centerContent && { display: "flex", alignItems: "center", justifyContent: "center" },
      ...rest
    };
  }
};
var patterns = {
  box,
  flex,
  stack,
  vstack,
  hstack,
  spacer,
  circle,
  absoluteCenter,
  grid,
  gridItem,
  wrap,
  container
};
var theme = {
  keyframes,
  breakpoints,
  tokens,
  textStyles
};
var config = {
  theme,
  conditions,
  utilities,
  patterns
};

// src/presets.ts
var presets_default = config;
export {
  presets_default as default
};
